@@ -63,7 +63,7 @@ class ActionTest(BaseSacrudTest):
         request['name'] = ["Vasya", ]
         request['fullname'] = ["Vasya Pupkin", ]
         request['password'] = ["", ]  # check empty value
-        request['groups[]'] = ["1", "3"]
+        request['groups[]'] = [u'["id", 1]', u'["id", 3]', u'["id" bad row]']
         request['badAttr'] = ["1", "bar"]
         request['badM2MAttr[]'] = ["1", "bar"]
 
@@ -76,6 +76,12 @@ class ActionTest(BaseSacrudTest):
         self.assertEqual([x.id for x in user.groups],
                          [group1.id, group3.id])
 
+        request['groups[]'] = None
+        CRUD(self.session, User, request=request).add()
+        user = self.session.query(User).get(1)
+        self.assertEqual([x.id for x in user.groups],
+                         [group1.id, group3.id])
+
         # Add profile
         request = DummyRequest().environ
         request['phone'] = ["213123123", ]
@@ -115,12 +121,18 @@ class ActionTest(BaseSacrudTest):
     def test_preprocessor(self):
         # Add profile
         request = DummyRequest().environ
-        request['datetime'] = "2012-12-12"
+        request['date'] = "2012-12-12"
+        request['datetime'] = "2012-12-12 12:12"
+        request['datetimeseconds'] = "2012-12-12 12:12:12"
         request["sak"] = "Ac"
         foo = CRUD(self.session, TypesPreprocessor, request=request).add()
         self.assertEqual(foo.sak, bytearray(b"Ac"))
-        self.assertEqual(foo.datetime,
+        self.assertEqual(foo.date,
                          datetime.datetime(2012, 12, 12, 0, 0))
+        self.assertEqual(foo.datetime,
+                         datetime.datetime(2012, 12, 12, 12, 12))
+        self.assertEqual(foo.datetimeseconds,
+                         datetime.datetime(2012, 12, 12, 12, 12, 12))
 
     def test_update(self):
 
